pub struct ModelArmorConfig {
pub prompt_template_name: Option<String>,
pub response_template_name: Option<String>,
}Expand description
Configuration for Model Armor integrations of prompt and responses.
This data type is not supported in Gemini API.
Fields
prompt_template_name: Option<String>Optional. The name of the Model Armor template to use for prompt sanitization.
response_template_name: Option<String>Optional. The name of the Model Armor template to use for response sanitization.