Module http
rust_
genai_
types
0.2.0
Module http
Module Items
Structs
In crate rust_
genai_
types
rust_genai_types
Module
http
Structs

Http
Options
HTTP options to be used in each of the requests.
Http
Response
A wrapper class for the HTTP response (SDK only).
Http
Retry
Options
HTTP retry options to be used in each of the requests.