pub struct HttpRetryOptions {
pub attempts: Option<u32>,
pub initial_delay: Option<f64>,
pub max_delay: Option<f64>,
pub exp_base: Option<f64>,
pub jitter: Option<f64>,
pub http_status_codes: Option<Vec<u16>>,
}Expand description
HTTP retry options to be used in each of the requests.
Fields
attempts: Option<u32>Maximum number of attempts, including the original request. If 0 or 1, it means no retries. If not specified, defaults to 5.
initial_delay: Option<f64>Initial delay before the first retry, in seconds. Defaults to 1.0.
max_delay: Option<f64>Maximum delay between retries, in seconds. Defaults to 60.0.
exp_base: Option<f64>Multiplier by which the delay increases after each attempt. Defaults to 2.0.
jitter: Option<f64>Randomness factor for the delay, in seconds. Defaults to 1.0.
http_status_codes: Option<Vec<u16>>List of HTTP status codes that should trigger a retry.
If not specified, a default set of retryable codes (408, 429, and select 5xx) is used.