pub struct CreateInteractionConfig {Show 15 fields
pub http_options: Option<HttpOptions>,
pub model: Option<String>,
pub agent: Option<String>,
pub input: InteractionInput,
pub tools: Option<Vec<Tool>>,
pub generation_config: Option<GenerationConfig>,
pub agent_config: Option<AgentConfig>,
pub background: Option<bool>,
pub store: Option<bool>,
pub previous_interaction_id: Option<String>,
pub response_format: Option<Value>,
pub response_mime_type: Option<String>,
pub response_modalities: Option<Vec<InteractionResponseModality>>,
pub system_instruction: Option<String>,
pub stream: Option<bool>,
}Expand description
Create Interaction 配置(请求体)。
Fields
http_options: Option<HttpOptions>Optional. HTTP request overrides (SDK only).
model: Option<String>The name of the Model used for generating the interaction.
agent: Option<String>The name of the Agent used for generating the interaction.
input: InteractionInputtools: Option<Vec<Tool>>generation_config: Option<GenerationConfig>agent_config: Option<AgentConfig>background: Option<bool>store: Option<bool>previous_interaction_id: Option<String>response_format: Option<Value>response_mime_type: Option<String>response_modalities: Option<Vec<InteractionResponseModality>>system_instruction: Option<String>stream: Option<bool>Implementations