pub struct GetInteractionConfig {
pub http_options: Option<HttpOptions>,
pub include_input: Option<bool>,
pub stream: Option<bool>,
pub last_event_id: Option<String>,
}Expand description
Get Interaction 配置。
Fields
http_options: Option<HttpOptions>include_input: Option<bool>If set to true, includes the input in the response.
stream: Option<bool>If set to true, the generated content will be streamed incrementally.
last_event_id: Option<String>Optional. Resumes the interaction stream from the next chunk after the event id.