CreateTuningJobConfig

Struct CreateTuningJobConfig 

pub struct CreateTuningJobConfig {
Show 22 fields pub http_options: Option<HttpOptions>, pub method: Option<TuningMethod>, pub validation_dataset: Option<TuningValidationDataset>, pub tuned_model_display_name: Option<String>, pub description: Option<String>, pub epoch_count: Option<i32>, pub learning_rate_multiplier: Option<f32>, pub export_last_checkpoint_only: Option<bool>, pub pre_tuned_model_checkpoint_id: Option<String>, pub adapter_size: Option<AdapterSize>, pub tuning_mode: Option<TuningMode>, pub custom_base_model: Option<String>, pub batch_size: Option<i32>, pub learning_rate: Option<f32>, pub evaluation_config: Option<EvaluationConfig>, pub encryption_spec: Option<EncryptionSpec>, pub labels: Option<HashMap<String, String>>, pub beta: Option<f32>, pub base_teacher_model: Option<String>, pub tuned_teacher_model_source: Option<String>, pub sft_loss_weight_multiplier: Option<f32>, pub output_uri: Option<String>,
}
Fine-tuning job creation request - optional fields.

Fields

http_options: Option<HttpOptions>

Optional. HTTP request overrides (SDK only, not sent to API).

method: Option<TuningMethod>validation_dataset: Option<TuningValidationDataset>tuned_model_display_name: Option<String>description: Option<String>epoch_count: Option<i32>learning_rate_multiplier: Option<f32>export_last_checkpoint_only: Option<bool>pre_tuned_model_checkpoint_id: Option<String>adapter_size: Option<AdapterSize>tuning_mode: Option<TuningMode>

Optional. Tuning mode for SFT tuning (Vertex AI only).

custom_base_model: Option<String>

Optional. Custom base model for tuning (Vertex AI OSS models only).

batch_size: Option<i32>learning_rate: Option<f32>evaluation_config: Option<EvaluationConfig>encryption_spec: Option<EncryptionSpec>

Optional. Customer-managed encryption key options for a TuningJob.

labels: Option<HashMap<String, String>>beta: Option<f32>base_teacher_model: Option<String>

Optional. The base teacher model that is being distilled (Distillation only).

tuned_teacher_model_source: Option<String>

Optional. The resource name of the tuned teacher model (Distillation only).

sft_loss_weight_multiplier: Option<f32>

Optional. Multiplier for adjusting the weight of the SFT loss (Distillation only).

output_uri: Option<String>

Optional. The Cloud Storage location where the tuning job outputs are written (Vertex AI only).